@@ -1,9 +1,9 @@
 package Log::ger::UseDataDumpColor;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-06-04'; # DATE
+our $DATE = '2020-06-06'; # DATE
 our $DIST = 'Log-ger-UseDataDumpColor'; # DIST
-our $VERSION = '0.003'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
 use Data::Dump::Color ();
 use Log::ger ();
@@ -26,7 +26,7 @@ Log::ger::UseDataDumpColor - Use Data::Dump::Color to dump data structures
 
 =head1 VERSION
 
-This document describes version 0.003 of Log::ger::UseDataDumpColor (from Perl distribution Log-ger-UseDataDumpColor), released on 2020-06-04.
+This document describes version 0.005 of Log::ger::UseDataDumpColor (from Perl distribution Log-ger-UseDataDumpColor), released on 2020-06-06.
 
 =head1 SYNOPSIS
 
@@ -56,9 +56,29 @@ L<Log::ger>
 
 L<Data::Dump::Color>
 
-Other modules to set data dumper for Log::ger: L<Log::ger::UseDataDump>,
-L<Log::ger::UseDataDumpObjectAsString>, L<Log::ger::UseDataDumpOptions>,
-L<Log::ger::UseDataDumper>, L<Log::ger::UseDataPrinter>.
+Other modules to set data dumper for Log::ger:
+
+=over
+
+=item * L<Log::ger::UseBaheForDump>
+
+=item * L<Log::ger::UseDataDump>
+
+=item * L<Log::ger::UseDataDumpObjectAsString>
+
+=item * L<Log::ger::UseDataDumpOptions>
+
+=item * L<Log::ger::UseDataDumper>
+
+=item * L<Log::ger::UseDataDumperCompact>
+
+=item * L<Log::ger::UseDataPrinter>
+
+=item * L<Log::ger::UseJSONForDump>
+
+=item * L<Log::ger::UseYAMLForDump>
+
+=back
 
 =head1 AUTHOR
 
